---

slug: /configurations-overview
---

# Pre-deployment configuration overview

To ensure that seekdb can be used effectively, you need to configure the operating system and installation environment as follows:

| Configuration item | Personal trial |Production environments |Description |
| ------ | ------- |---| ---- |
| [Create a user](300.create-regular-user.md) | You can use the root user.|It is recommended to use a user with sudo privileges.| You can use a regular user with sudo privileges. |
| [Plan disks](400.plan-disks.md) |No configuration is required.|It is recommended to configure.| In production environments, it is recommended to use different disks for the log storage directory and data storage directory to avoid performance issues in high-pressure scenarios when both directories are planned on the same disk. |
| [Configure limits.conf](500.configure-limits-conf.md) | No configuration is required.|Configuration is required.| Improves the stability and performance of seekdb during runtime. |
| [Configure sysctl.conf](600.configure-sysctl-conf.md) | No configuration is required.|Configuration is required.| Improves Linux system performance, thereby improving seekdb performance. |
| [Disable the firewall and SELinux](700.disable-firewall-and-selinux.md) | No configuration is required.|Configuration is required.| Prevents access to the database from being blocked. |
